View Source TwitchAPI.AuthFile (hello_twitch_api v0.5.3)
Some functions to read and write Twitch Auth from and to a file.
Summary
Functions
The full filename for auth.
Some functions to read and write Twitch Auth from and to a file.
The full filename for auth.